package sun.security.util;

import java.util.regex.PatternSyntaxException;
import sun.security.action.GetPropertyAction;
import java.security.InvalidParameterException;

public final class SecurityProviderConstants
{
    private static final Debug debug;
    public static final int DEF_DSA_KEY_SIZE;
    public static final int DEF_RSA_KEY_SIZE;
    public static final int DEF_RSASSA_PSS_KEY_SIZE;
    public static final int DEF_DH_KEY_SIZE;
    public static final int DEF_EC_KEY_SIZE;
    private static final String KEY_LENGTH_PROP = "jdk.security.defaultKeySize";
    
    private SecurityProviderConstants() {
    }
    
    public static final int getDefDSASubprimeSize(int i) {
        if (i <= 1024) {
            return 160;
        }
        if (i == 2048) {
            return 224;
        }
        if (i == 3072) {
            return 256;
        }
        throw new InvalidParameterException("Invalid DSA Prime Size: " + i);
    }
    
    static {
        debug = Debug.getInstance("jca", "ProviderConfig");
        String privilegedGetProperty = GetPropertyAction.privilegedGetProperty("jdk.security.defaultKeySize");
        int def_DSA_KEY_SIZE = 2048;
        int n = 2048;
        int def_DH_KEY_SIZE = 2048;
        int def_EC_KEY_SIZE = 256;
        if (privilegedGetProperty != null) {
            try {
                String[] split;
                for (String str : split = privilegedGetProperty.split(",")) {
                    String[] split2 = str.split(":");
                    if (split2.length != 2) {
                        if (SecurityProviderConstants.debug != null) {
                            SecurityProviderConstants.debug.println("Ignoring invalid pair in jdk.security.defaultKeySize property: " + str);
                        }
                    }
                    else {
                        String upperCase = split2[0].trim().toUpperCase();
                        int int1;
                        try {
                            int1 = Integer.parseInt(split2[1].trim());
                        }
                        catch (NumberFormatException ex) {
                            if (SecurityProviderConstants.debug != null) {
                                SecurityProviderConstants.debug.println("Ignoring invalid value in jdk.security.defaultKeySize property: " + str);
                            }
                            continue;
                        }
                        if (upperCase.equals("DSA")) {
                            def_DSA_KEY_SIZE = int1;
                        }
                        else if (upperCase.equals("RSA")) {
                            n = int1;
                        }
                        else if (upperCase.equals("RSASSA-PSS")) {
                            n = int1;
                        }
                        else if (upperCase.equals("DH")) {
                            def_DH_KEY_SIZE = int1;
                        }
                        else if (upperCase.equals("EC")) {
                            def_EC_KEY_SIZE = int1;
                        }
                        else {
                            if (SecurityProviderConstants.debug != null) {
                                SecurityProviderConstants.debug.println("Ignoring unsupported algo in jdk.security.defaultKeySize property: " + str);
                                continue;
                            }
                            continue;
                        }
                        if (SecurityProviderConstants.debug != null) {
                            SecurityProviderConstants.debug.println("Overriding default " + upperCase + " keysize with value from " + "jdk.security.defaultKeySize" + " property: " + int1);
                        }
                    }
                }
            }
            catch (PatternSyntaxException obj) {
                if (SecurityProviderConstants.debug != null) {
                    SecurityProviderConstants.debug.println("Unexpected exception while parsing jdk.security.defaultKeySize property: " + obj);
                }
            }
        }
        DEF_DSA_KEY_SIZE = def_DSA_KEY_SIZE;
        DEF_RSA_KEY_SIZE = n;
        DEF_RSASSA_PSS_KEY_SIZE = n;
        DEF_DH_KEY_SIZE = def_DH_KEY_SIZE;
        DEF_EC_KEY_SIZE = def_EC_KEY_SIZE;
    }
}
